jactorch.data.layout
====================

.. automodule:: jactorch.data.layout

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      DataLayout
      DataLayoutSpec
      DataLayoutType
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      concat
      pad
      pad2d
      padimage
      skip
      stack
   
   

   
   
   








.. rubric:: Class DataLayout
.. autoclass:: DataLayout
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class DataLayoutSpec
.. autoclass:: DataLayoutSpec
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class DataLayoutType
.. autoclass:: DataLayoutType
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: concat

.. autofunction:: pad

.. autofunction:: pad2d

.. autofunction:: padimage

.. autofunction:: skip

.. autofunction:: stack


